@@ -109,7 +109,7 @@ readLayout <- function(opts = simOptions(), xyCompare = c("union","intersect"))
   
   if(opts$typeLoad == 'api'){
     # browser()
-    areas <- read_secure_json(paste0(path, "&depth=4"), opts$token, timeout = opts$timeout)
+    areas <- read_secure_json(paste0(path, "&depth=4"), token = opts$token, timeout = opts$timeout, config = opts$httr_config)
     # areas <- areas[names(areas) %in% opts$areaList]
     areas <- areas[!names(areas) %in% c("list", "sets")]
     areas <- rbindlist(mapply(function(X, Y){
